@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2019-05-06'; # DATE
-our $VERSION = '0.443'; # VERSION
+our $DATE = '2019-06-05'; # DATE
+our $VERSION = '0.444'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,16 +55,33 @@ _
     # when uploading. i'm defaulting to a retries=2.
     # 2017-06-28 - increase default to retries=7.
     # 2017-06-28 - tone down retries to 5.
+    # 2019-06-05 - now uses exponential backoff, increase retries to 35 to try
+    #              for a little over a day
     retries => {
         summary => 'Number of retries when received 5xx HTTP error from server',
         schema  => 'int*',
-        default => 5,
+        default => 35,
         tags    => ['common'],
     },
     retry_delay => {
-        summary => 'How long to wait before retrying',
+        summary => 'How long to wait before retrying (deprecated)',
         schema  => 'duration*',
-        default => 3,
+        tags    => ['common', 'deprecated'],
+        description => <<'_',
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default `retries` of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via `retry_max_delay`.
+
+_
+    },
+    retry_max_delay => {
+        summary => 'How long to wait at most before retrying',
+        schema  => 'duration*',
+        default => 3600,
         tags    => ['common'],
     },
 );
@@ -153,10 +170,34 @@ sub _common_args {
 sub _request {
     require HTTP::Request::Common;
 
+    state $deprecation_warned = 0;
+
     my %args = @_;
     # XXX schema
-    $args{retries} //= 5;
-    $args{retry_delay} //= 3;
+    $args{retries} //= 35;
+    if (defined $args{retry_delay}) {
+        warn "retry_delay setting is deprecated, please use retry_max_delay from now on\n"
+            unless $deprecation_warned++;
+    } else {
+        $args{retry_delay} = 3;
+    }
+    $args{retry_max_delay} //= 3600;
+
+    my $strategy;
+    if (defined $args{retry_delay}) {
+        require Algorithm::Backoff::Constant;
+        $strategy = Algorithm::Backoff::Constant->new(
+            max_attempts  => $args{retries},
+            delay         => $args{retry_delay},
+        );
+    } else {
+        require Algorithm::Backoff::Exponential;
+        $strategy = Algorithm::Backoff::Exponential->new(
+            max_attempts  => $args{retries},
+            initial_delay => 3,
+            max_delay     => $args{retry_max_delay},
+        );
+    }
 
     # set default for username and password from ~/.pause
     my $username = $args{username};
@@ -188,13 +229,15 @@ sub _request {
   RETRY:
     while (1) {
         $resp = $ua->request($req);
-        if ($resp->code =~ /^[5]/ && $args{retries} >= ++$tries) {
-            log_warn("Got error %s (%s) from server when POST-ing to %s%s, retrying (%d/%d) ...",
+        if ($resp->code =~ /^[5]/) {
+            $tries++;
+            my $delay = $strategy->failure;
+            log_warn("Got error %s (%s) from server when POST-ing to %s%s, retrying (%d/%d) in %d second(s) ...",
                      $resp->code, $resp->message,
                      $url,
                      $args{note} ? " ($args{note})" : "",
-                     $tries, $args{retries});
-            sleep $args{retry_delay};
+                     $tries, $args{retries}, $delay);
+            sleep $delay;
             next;
         }
         last;
@@ -905,7 +948,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.443 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2019-05-06.
+This document describes version 0.444 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2019-06-05.
 
 =head1 SYNOPSIS
 
@@ -953,13 +996,24 @@ not yet supported.
 
 Protect some files/wildcard patterns from delete/cleanup.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<username> => I<str>
 
@@ -992,7 +1046,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 delete_old_releases
 
 Usage:
@@ -1040,13 +1093,24 @@ not yet supported.
 
 Protect some files/wildcard patterns from delete/cleanup.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<username> => I<str>
 
@@ -1079,7 +1143,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 list_dists
 
 Usage:
@@ -1121,13 +1184,24 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<username> => I<str>
 
@@ -1150,7 +1224,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 list_files
 
 Usage:
@@ -1188,13 +1261,24 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<size_max> => I<uint>
 
@@ -1221,7 +1305,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 list_modules
 
 Usage:
@@ -1251,13 +1334,24 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<type> => I<str>
 
@@ -1284,7 +1378,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 reindex_files
 
 Usage:
@@ -1313,13 +1406,24 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<username> => I<str>
 
@@ -1352,7 +1456,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 undelete_files
 
 Usage:
@@ -1385,13 +1488,24 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<username> => I<str>
 
@@ -1424,7 +1538,6 @@ that contains extra information.
 Return value:  (any)
 
 
-
 =head2 upload_files
 
 Usage:
@@ -1462,13 +1575,24 @@ PAUSE password.
 If unset, default value will be searched from C<~/.pause>. Encrypted C<.pause> is
 not yet supported.
 
-=item * B<retries> => I<int> (default: 5)
+=item * B<retries> => I<int> (default: 35)
 
 Number of retries when received 5xx HTTP error from server.
 
-=item * B<retry_delay> => I<duration> (default: 3)
+=item * B<retry_delay> => I<duration>
 
-How long to wait before retrying.
+How long to wait before retrying (deprecated).
+
+This setting is now deprecated. Will use a constant backoff strategy of delaying
+this many seconds. The default (when this setting is not specified) is now to
+use an exponential backoff strategy of delaying 3, 6, 12, 24, ..., 3600, 3600,
+... seconds. The default C<retries> of 35 makes this strategy retries for a
+little over a day (88941 seconds). The terminal delay setting (default 3600
+seconds) can be set via C<retry_max_delay>.
+
+=item * B<retry_max_delay> => I<duration> (default: 3600)
+
+How long to wait at most before retrying.
 
 =item * B<subdir> => I<str> (default: "")
 
